Filter Methods
==============

Cost Based Filter Methods
-------------------------

.. toctree::
   :glob:
   :maxdepth: 1

   filter_methods/cost_based_filter_methods

No-Cost Based Filter Methods
----------------------------

.. toctree::
   :glob:
   :maxdepth: 1

   filter_methods/no_cost_based_filter_methods